##
## Copyright (c) 2006 Jason Dillon
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##     http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
##

##
## $Id: reviews.py 26 2006-04-15 06:25:53Z user57 $
##

import re

from p4spam.perforce import P4Field, P4Code, P4Exception
from p4spam.perforce.commands import ResultSupport, StreamedResultCommand

COMMAND_NAME = "reviews"

##
## ReviewsCommand
##

class ReviewsCommand(StreamedResultCommand):
    def __init__(this, p4):
        StreamedResultCommand.__init__(this, COMMAND_NAME, p4)
    
    def createResult(this, entry):
        return ReviewerInfo(entry)

class ReviewerInfo(ResultSupport):
    
    # jdillon <jason@planet57.com> (Jason Dillon)
    DATA_RE = re.compile(r'^(\S+) <(\S+)> \((.+)\)$')
    
    def __init__(this, entry):
        if entry[P4Field.CODE] == P4Code.INFO:
            (this.user, this.email, this.fullname) = \
                this.DATA_RE.match(entry[P4Field.DATA]).groups()
        
        elif entry[P4Field.CODE] == P4Code.STAT:
            this.user = entry['user']
            this.email = entry['email']
            this.fullname = entry['name']
        
        else:
            assert "Unexpected data: %s" % str(entry)
    
    def toString(this):
        return "%s <%s> (%s)" % (this.user, this.email, this.fullname)
    
    def __str__(this):
        return this.toString()
    
    def __repr__(this):
        return this.toString()

##
## perforce.commands factory interface
##

def create(p4):
    return ReviewsCommand(p4)

